@@ -78,6 +78,36 @@ class H2OAutoMLBuildControlParams(Params):
         """Path to a directory where every generated model will be stored.""",
         H2OTypeConverters.toNullableString())
 
+    distribution = Param(
+        Params._dummy(),
+        "distribution",
+        """Distribution function used by algorithms that support it; other algorithms use their defaults.""",
+        H2OTypeConverters.toEnumString("hex.genmodel.utils.DistributionFamily"))
+
+    tweediePower = Param(
+        Params._dummy(),
+        "tweediePower",
+        """Tweedie power for Tweedie regression, must be between 1 and 2.""",
+        H2OTypeConverters.toFloat())
+
+    quantileAlpha = Param(
+        Params._dummy(),
+        "quantileAlpha",
+        """Desired quantile for Quantile regression, must be between 0 and 1.""",
+        H2OTypeConverters.toFloat())
+
+    huberAlpha = Param(
+        Params._dummy(),
+        "huberAlpha",
+        """Desired quantile for Huber/M-regression (threshold between quadratic and linear loss, must be between 0 and 1).""",
+        H2OTypeConverters.toFloat())
+
+    customDistributionFunc = Param(
+        Params._dummy(),
+        "customDistributionFunc",
+        """Reference to custom distribution, format: `language:keyName=funcName`""",
+        H2OTypeConverters.toNullableString())
+
     ##
     # Getters
     ##
@@ -108,6 +138,21 @@ class H2OAutoMLBuildControlParams(Params):
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
+    def getDistribution(self):
+        return self.getOrDefault(self.distribution)
+
+    def getTweediePower(self):
+        return self.getOrDefault(self.tweediePower)
+
+    def getQuantileAlpha(self):
+        return self.getOrDefault(self.quantileAlpha)
+
+    def getHuberAlpha(self):
+        return self.getOrDefault(self.huberAlpha)
+
+    def getCustomDistributionFunc(self):
+        return self.getOrDefault(self.customDistributionFunc)
+
     ##
     # Setters
     ##
@@ -137,3 +182,18 @@ class H2OAutoMLBuildControlParams(Params):
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
+
+    def setDistribution(self, value):
+        return self._set(distribution=value)
+
+    def setTweediePower(self, value):
+        return self._set(tweediePower=value)
+
+    def setQuantileAlpha(self, value):
+        return self._set(quantileAlpha=value)
+
+    def setHuberAlpha(self, value):
+        return self._set(huberAlpha=value)
+
+    def setCustomDistributionFunc(self, value):
+        return self._set(customDistributionFunc=value)
